@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.131_01';
+our $VERSION = '0.100';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -196,6 +196,7 @@ my %statatr = (		# for convenience of get() and put().
 
 __PACKAGE__->alias (iridium => __PACKAGE__);
 
+
 #	Pre-compute the transform vectors for each of the three Main
 #	Mission Antennae, so that we do not have to repeatedly compute
 #	the sin and cos of the relevant angles. The transform we are
@@ -223,6 +224,7 @@ __PACKAGE__->alias (iridium => __PACKAGE__);
 #	  | -cos(theta) * sin(phi)   sin(theta) * sin(phi)  cos(phi) |
 #	  +-                                                        -+
 
+
 my @transform_vector;
 {	# Begin local symbol block.
 my $cosphi = cos (MMAPHI);
@@ -241,6 +243,7 @@ foreach my $mma (0 .. 2) {
     }
 }	# End local symbol block.
 
+
 #	We also pre-compute the inverse transforms, to facilitate the
 #	recovery of the virtual image of the illuminating body.
 
@@ -288,8 +291,10 @@ EOD
     }
 }
 
+
 #	see Astro::Coord::ECI->attribute ();
 
+
 sub attribute {
     my ($self, $name) = @_;
     return exists $accessor{$name} ?
@@ -297,6 +302,7 @@ sub attribute {
 	$self->SUPER::attribute ($name);
 }
 
+
 =item $tle->before_reblessing ()
 
 This method supports reblessing into a subclass. It is intended to do
@@ -314,6 +320,7 @@ sub before_reblessing {
     return;
 }
 
+
 =item $tle->can_flare ($spare);
 
 This method returns true (in the Perl sense) if the object is capable
@@ -333,6 +340,7 @@ sub can_flare {
     return !$status || $spare && $status == $self->BODY_STATUS_IS_SPARE;
 }
 
+
 =item @flares = $tle->flare ($sta, $start, $end);
 
 This method returns the list of flares produced by the given Iridium
@@ -419,13 +427,12 @@ is taken into account, as is atmospheric extinction. Non-specular
 flares are calculated by a fairly arbitrary equation whose coefficients
 were fitted to visual flare magnitude estimates collected by Ron Lee
 and made available on the Web by Randy John as part of his skysat
-web site at C<http://home.comcast.net/~skysat/> (missing; see
-L<ACKNOWLEDGMENTS|/ACKNOWLEDGMENTS>). Atmospheric extinction
+web site at L<http://home.comcast.net/~skysat/>. Atmospheric extinction
 is also taken into account for the non-specular flares.
 
 Atmospheric extinction is calculated according to the article by Daniel
 W.  Green in the July 1992 issue of "International Comet Quarterly", and
-available at L<http://www.icq.eps.harvard.edu/ICQExtinct.html>. Because
+available at L<http://www.cfa.harvard.edu/icq/ICQExtinct.html>. Because
 Heavens Above does not display flares dimmer than a certain magnitude
 (-6 for day flares, and apparently 0 for night flares), it may not
 display a flare that this code predicts. I have no information how
@@ -456,10 +463,10 @@ CelesTrak (L<http://celestrak.com/SpaceTrack/query/iridium.txt>), since
 it represents one-stop shopping, and Dr. Kelso has expressed the intent
 to check with Iridium Satellite LLC monthly for status. Mike McCants'
 "Status of Iridium Payloads" at
-C<http://users2.ev1.net/~mmccants/tles/iridium.html> (no longer
-maintained) noted that flares may be unreliable for spares, so can_flare
-() returns false for them. If this is not what you want, call can_flare
-with a true value (e.g. C<can_flare( 1 )>).
+L<http://users2.ev1.net/~mmccants/tles/iridium.html> notes that flares
+may be unreliable for spares, so can_flare () returns false for them. If
+this is not what you want, call can_flare with a true value (e.g.
+can_flare(1)).
 
 Fourth, the Heavens Above definition of 'daytime' differs from mine.
 Heavens Above does not document what their definition is, at least
@@ -549,6 +556,7 @@ eod
     my $night_limit = $twilight + DAY_TOLERANCE;
     my $illum_tolerance = deg2rad (15);
 
+
 #	We assume our observing location is fixed on the surface of the
 #	Earth, and take advantage of the fact that an Iridium orbit is
 #	very nearly polar. We use these to calculate the intervals
@@ -594,17 +602,20 @@ eod
 	$self->universal ($time);
 	my ($satlat, $satlon, $satalt) = $self->geodetic;
 
+
 #	Correct time to put satellite at same latitude as station.
 
 	$time += ($asc ? $stalat - $satlat : $satlat - $stalat)
 	    / $angular_velocity;
 	($satlat, $satlon, $satalt) = $self->universal ($time)->geodetic;
 
+
 #	Calculate whether satellite is above horizon.
 
 	my ( undef, $elev, $rng ) = $station->azel_offset( $self, 0 );
 	$elev > $horizon or next;
 
+
 #	Check whether we are interested in this potential flare, based
 #	on whether it might be during the day, or am, or pm.
 
@@ -622,12 +633,14 @@ eod
 	    0;
 	    } || next);
 
+
 #	Calculate whether the satellite is illuminated.
 
 ##	my $lit = ($self->azel ($illum->universal ($time)))[1] >=
 	($self->azel ($illum->universal ($time)))[1] >=
 	    $self->dip () - $illum_tolerance or next;
 
+
 #	For our screening to work we need to know the maximum angular
 #	distance we can travel in 30 seconds. This is the arc tangent
 #	of the velocity over the range
@@ -638,6 +651,7 @@ eod
 	    * 30;
 	$max_angle += $max_mirror_angle;	# Take into account near misses.
 
+
 #	Iterate over a period of 16 minutes centered on our current
 #	time, calculating the location of the reflection of the sun
 #	versus the satellite, as seen by the observer.
@@ -646,6 +660,7 @@ eod
 	foreach my $deltat (-8 .. 8) {
 	    my $time = $deltat * 60 + $time;
 
+
 #	See if the satellite is illuminated at this time.
 #	TODO This code may need some slop; specifically we might want to
 #	assume the Sun is higher than it actually is by $max_angle.
@@ -653,6 +668,7 @@ eod
 	    ($self->universal ($time)->azel ($illum->universal ($time)))[1] >=
 		$self->dip () or next;
 
+
 #	Transform the relevant coordinates into a coordinate system
 #	in which the axis of the satellite is along the Z axis (with
 #	the Earth in the negative Z direction) and the direction of
@@ -664,11 +680,13 @@ eod
 		$self->_flare_transform_coords_list (
 		$illum, $station->universal( $time ) );
 
+
 #	Now we do a second iteration over the Main Mission Antennae,
 #	checking for the position of the Sun's reflection.
 
 	    foreach my $mma (0 .. 2) {
 
+
 #	We clone the sun and the station, and then calculate the angle
 #	between the satellite and the reflection of the Sun, as seen by
 #	the observer. We skip to the next antenna if no reflection is
@@ -680,26 +698,31 @@ eod
 		    my $angle = _flare_calculate_angle_list(
 		    $mma, $illum_vector, $station_vector ) );
 
+
 #	Save the angle, time, and cloned station for subsequent
 #	analysis.
 
 		push @{$flare_potential[$mma]},
 		    [$angle, $time, $illum_vector, $station_vector];
 
+
 #	End of iterating over Main Mission Antennae.
 
 	    }
 
+
 #	End of iterating over 16 minute period centered on current
 #	time.
 
 	}
 
+
 #	Now iterate over each MMA to calculate its flare, if any.
 
 MMA_LOOP:
 	foreach my $mma (0 .. 2) {
 
+
 #	Find the best possibility for a flare. If none, or the angle is
 #	more than the max possible, ignore this antenna.
 
@@ -736,6 +759,7 @@ MMA_LOOP:
 		    $flare_potential[$mma][$inx + 1]);
 	    };	# End local symbol block;
 
+
 #	Use successive approximation to find the time of minimum
 #	angle. We can not use a linear split-the-difference search,
 #	because the behavior is too far from linear. So we fudge by
@@ -746,6 +770,7 @@ MMA_LOOP:
 
 	    while (abs ($flare_approx[1][1] - $flare_approx[0][1]) > .1) {
 
+
 #	Calculate the next time to try as a weighted average of the
 #	previous two approximations, with the worse approximation
 #	having three times the weight of the better one. This prevents
@@ -759,6 +784,7 @@ MMA_LOOP:
 		my $time = ($flare_approx[1][1] * 3 + $flare_approx[0][1]) / 4;
 ####		my $time = ($flare_approx[1][1] * 6 + $flare_approx[0][1]) / 7;
 
+
 #	Transform the relevant coordinates into a coordinate system
 #	in which the axis of the satellite is along the Z axis (with
 #	the Earth in the negative Z direction) and the direction of
@@ -771,6 +797,7 @@ MMA_LOOP:
 			$illum->universal( $time ),
 			$station->universal( $time ) );
 
+
 #	Calculate the angle between the satellite and the reflection
 #	of the Sun, as seen by the observer.
 
@@ -778,25 +805,30 @@ MMA_LOOP:
 		    $mma, $illum_vector, $station_vector );
 		defined $angle or next MMA_LOOP;
 
+
 #	Store the data in our approximation list, in order by angle.
 
 		pop @flare_approx;
 		splice @flare_approx, $angle >= $flare_approx[0][0], 0,
 		    [$angle, $time, $illum_vector, $station_vector];
 
+
 #	End of successive approximation of time of minimum angle.
 
 	    }
 
+
 #	Pull the (potential) flare data off the approximation list.
 
 	    my ($angle, $time, $illum_vector, $station_vector) =
 		    @{$flare_approx[0]};
 
+
 #	Skip it if the mirror angle is greater than the max.
 
 	    next if $angle > $max_mirror_angle;
 
+
 #	All our approximations may have left us with a satellite which
 #	is not quite lit. This happened with Iridium 32 (OID 24945) on
 #	Feb 03 2007 at 07:45:19 PM. So we check for illumination one
@@ -809,6 +841,7 @@ MMA_LOOP:
 	    ($self->universal ($time)->azel ($illum->universal ($time)))[1] >=
 		$self->dip () or next;
 
+
 #	Calculate all the flare data.
 
 	    my $flare = $self->_flare_char_list ($station, $mma, $angle,
@@ -819,10 +852,12 @@ MMA_LOOP:
 	    push @flares, $flare
 		if !$flare->{status} && $want{$flare->{type}};
 
+
 #	End of iteration over each MMA to calculate its flare.
 
 	}
 
+
 #	Compute the next approxiate crossing of the observer's
 #	latitude.
 
@@ -835,6 +870,7 @@ MMA_LOOP:
 
 }
 
+
 #	[$angle, $time, $illum_vector, $station_vector] =
 #	    $self->_flare_entrance ($illum, $station, $mma, $start,
 #	    $end);
@@ -939,6 +975,7 @@ sub _flare_transform_coords_inverse_list {
     return @rslt;
 }
 
+
 #	$angle = _flare_calculate_angle_list($mma, $illum, $station)
 
 #	This private subroutine calculates the angle between the
@@ -978,6 +1015,7 @@ sub _flare_calculate_angle_list {
     return _list_angle( $station, $illum, [ 0, 0, 0 ] );
 }
 
+
 #	$hash_ref = $iridium->_flare_char_list (...)
 #
 #	Calculate the characteristics of the flare of the given body.
@@ -1005,11 +1043,13 @@ if ($elev < $horizon) {
 	'Satellite %.2f degrees below horizon', rad2deg ($horizon - $elev)));
     }
 
+
 #	Retrieve the illuminating body information.
 
 my $illum = $self->get ('illum');
 my $illum_radius = $illum->get ('diameter') / 2;
 
+
 #	Retrieve missing station information.
 
 my $height = ($station->geodetic)[2];
@@ -1020,6 +1060,7 @@ my $sun = $self->get( 'sun' );
 my $twilight = $self->get ('twilight');
 my $atm_extinct = $self->get ('extinction');
 
+
 #	Calculate the range to the satellite, and to the reflection of
 #	the Sun, from the observer.
 
@@ -1064,11 +1105,13 @@ my $central_mag = $central_magnitude + $area_correction;
 
 #	And for the test case, I got -8.0. Amazing.
 
+
 #	Calculate the atmospheric extinction of the flare.
 
 my $extinction = $atm_extinct ?
 	atmospheric_extinction ($elev, $height) : 0;
 
+
 #	The following off-axis magnitude calculation is the result of
 #	normalizing Ron Lee's magnitude data (made available by Randy
 #	John in various forms at http://home.comcast.net/~skysat/ ) for
@@ -1143,12 +1186,14 @@ my $flare_mag = $limb_darkening > 0 ? do {
 	$extinction;
     min ($specular_mag, $off_axis_mag) } : $off_axis_mag;
 
+
 #	Compute the flare type (am, day, or pm)
 
 my $sun_elev = ($station->azel ($sun->universal ($time)))[1];
 my $flare_type = $sun_elev >= $twilight ? 'day' :
 	( $self->_time_in_zone( $time ) )[2] > 12 ? 'pm' : 'am';
 
+
 #	Compute the angle from the Sun to the flare.
 
 my $sun_angle = $station->angle ($sun, $self);
@@ -1194,6 +1239,7 @@ my ($virtual_image, $image_vector) = do {
     ];
     $image_vector->[2] = - $image_vector->[2];
 
+
     # Undo the rotations that placed the MMA of interest in the X-Y
     # plane.
 
@@ -1202,6 +1248,7 @@ my ($virtual_image, $image_vector) = do {
 	    $inverse_transform_vector[$mma][$_] ) } 0 .. 2
     ];
 
+
     # Transform from satellite-local coordinates to ECI coordinates.
 
     ( $image_vector ) = $self->_flare_transform_coords_inverse_list(
@@ -1214,6 +1261,7 @@ my ($virtual_image, $image_vector) = do {
 	$image_vector );
     };
 
+
 #	Compute the distance to the flare center.
 
 #	For the calculation, consider the Earth flat, and consider the
@@ -1256,6 +1304,7 @@ my $sub_vector = do {
 my $sub_point = Astro::Coord::ECI->new(
     station => $station )->universal( $time )->eci( @$sub_vector );
 
+
 #	Stash the data.
 
 my %rslt = (
@@ -1286,6 +1335,7 @@ my %rslt = (
 return wantarray ? %rslt : \%rslt;
 }
 
+
 #	$ainv = _invert_matrix_list ($a)
 
 #	This subroutine takes a reference to a list of three list
@@ -1396,6 +1446,7 @@ sub magnitude {
     return $mag;
 }
 
+
 =item @data = $tle->reflection ($station, $time)
 
 This method returns a list of references to hashes containing the same
@@ -1430,6 +1481,7 @@ sub reflection {
     return $self->$method( $station, $time );
 }
 
+
 # Called as $self->$method, above
 sub _reflection_fixed {	## no critic (ProhibitUnusedPrivateSubroutines)
     my ( $self, $station, $time ) = @_;
@@ -1438,6 +1490,7 @@ sub _reflection_fixed {	## no critic (ProhibitUnusedPrivateSubroutines)
     my $debug = $self->get ('debug');
     my $illum = $self->get ('illum')->universal ($time);
 
+
 #	Calculate whether satellite is above horizon.
 
     my (undef, $elev) = $station->universal ($time)->
@@ -1446,6 +1499,7 @@ sub _reflection_fixed {	## no critic (ProhibitUnusedPrivateSubroutines)
 	sprintf ('Satellite %.2f degrees below horizon', rad2deg (-$elev)))
 	unless $elev >= 0;
 
+
 #	Calculate whether the satellite is illuminated.
 
     my $lit = ($self->azel ($illum->universal ($time)))[1] - $self->dip ();
@@ -1454,6 +1508,7 @@ sub _reflection_fixed {	## no critic (ProhibitUnusedPrivateSubroutines)
 	    rad2deg (-$lit)))
 	unless $lit >= 0;
 
+
 #	Transform the relevant coordinates into a coordinate system
 #	in which the axis of the satellite is along the Z axis (with
 #	the Earth in the negative Z direction) and the direction of
@@ -1488,6 +1543,7 @@ eod
     return wantarray ? @rslt : \@rslt;
 }
 
+
 =item $tle->set ($name => $value ...)
 
 This method sets the value of the given attribute (or attributes).
@@ -1575,6 +1631,7 @@ sub __parse_name {
     }
 }
 
+
 {
 
     my %status_map = (
@@ -1623,14 +1680,8 @@ sub _set_operational_status {
 
 # All Iridium Classic satellites.
 #
-# Generated by Astro::SpaceTrack
-# $ tools/all_iridium_classic -iridium -indent=0
-# on Mon Jun 29 12:08:42 2020 GMT
-#
-# The following static method is UNSUPPORTED, and exists solely for the
-# benefit of xt/author/iridium_status.t. It may be modified or revoked
-# at any time.
-sub __iridium_status_as_of { return( qw{ 7 16 11 29 5 2020 } ) }
+# Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
+# on Fri Jul 13 14:43:18 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1639,103 +1690,103 @@ __PACKAGE__->status( add => 24794, iridium => 'D', 'Iridium 6', 'Decayed 2017-12
 __PACKAGE__->status( add => 24795, iridium => '-', 'Iridium 5', 'Tumbling' );
 __PACKAGE__->status( add => 24796, iridium => '-', 'Iridium 4', 'Tumbling' );
 __PACKAGE__->status( add => 24836, iridium => '-', 'Iridium 914', 'Tumbling' );
-__PACKAGE__->status( add => 24837, iridium => 'D', 'Iridium 12', 'Decayed 2018-09-02' );
+__PACKAGE__->status( add => 24837, iridium => 'S', 'Iridium 12', '' );
 __PACKAGE__->status( add => 24838, iridium => 'D', 'Iridium 9', 'Decayed 2003-03-11' );
-__PACKAGE__->status( add => 24839, iridium => 'D', 'Iridium 10', 'Decayed 2018-10-06' );
+__PACKAGE__->status( add => 24839, iridium => '+', 'Iridium 10', '' );
 __PACKAGE__->status( add => 24840, iridium => 'D', 'Iridium 13', 'Decayed 2018-04-29' );
 __PACKAGE__->status( add => 24841, iridium => '-', 'Iridium 16', 'Tumbling' );
 __PACKAGE__->status( add => 24842, iridium => '-', 'Iridium 911', 'Tumbling' );
-__PACKAGE__->status( add => 24869, iridium => 'D', 'Iridium 15', 'Decayed 2018-10-14' );
+__PACKAGE__->status( add => 24869, iridium => 'S', 'Iridium 15', '' );
 __PACKAGE__->status( add => 24870, iridium => '-', 'Iridium 17', 'Tumbling' );
 __PACKAGE__->status( add => 24871, iridium => '-', 'Iridium 920', 'Tumbling' );
-__PACKAGE__->status( add => 24872, iridium => 'D', 'Iridium 18', 'Decayed 2018-08-19' );
+__PACKAGE__->status( add => 24872, iridium => '-', 'Iridium 18', 'Tumbling' );
 __PACKAGE__->status( add => 24873, iridium => '-', 'Iridium 921', 'Tumbling' );
 __PACKAGE__->status( add => 24903, iridium => '-', 'Iridium 26', 'Tumbling' );
 __PACKAGE__->status( add => 24904, iridium => 'D', 'Iridium 25', 'Decayed 2018-05-14' );
-__PACKAGE__->status( add => 24905, iridium => 'D', 'Iridium 46', 'Decayed 2019-05-11' );
+__PACKAGE__->status( add => 24905, iridium => '-', 'Iridium 46', 'Tumbling' );
 __PACKAGE__->status( add => 24906, iridium => 'D', 'Iridium 23', 'Decayed 2018-03-28' );
 __PACKAGE__->status( add => 24907, iridium => '-', 'Iridium 22', 'Tumbling' );
 __PACKAGE__->status( add => 24925, iridium => '-', 'Dummy mass 1', 'Tumbling' );
 __PACKAGE__->status( add => 24926, iridium => '-', 'Dummy mass 2', 'Tumbling' );
 __PACKAGE__->status( add => 24944, iridium => '-', 'Iridium 29', 'Tumbling' );
-__PACKAGE__->status( add => 24945, iridium => 'D', 'Iridium 32', 'Decayed 2019-03-10' );
+__PACKAGE__->status( add => 24945, iridium => '+', 'Iridium 32', '' );
 __PACKAGE__->status( add => 24946, iridium => '-', 'Iridium 33', 'Tumbling' );
 __PACKAGE__->status( add => 24947, iridium => 'D', 'Iridium 27', 'Decayed 2002-02-01' );
 __PACKAGE__->status( add => 24948, iridium => '-', 'Iridium 28', 'Tumbling' );
 __PACKAGE__->status( add => 24949, iridium => 'D', 'Iridium 30', 'Decayed 2017-09-28' );
-__PACKAGE__->status( add => 24950, iridium => 'D', 'Iridium 31', 'Decayed 2018-12-20' );
+__PACKAGE__->status( add => 24950, iridium => 'S', 'Iridium 31', '' );
 __PACKAGE__->status( add => 24965, iridium => 'D', 'Iridium 19', 'Decayed 2018-04-07' );
-__PACKAGE__->status( add => 24966, iridium => 'D', 'Iridium 35', 'Decayed 2018-12-26' );
+__PACKAGE__->status( add => 24966, iridium => 'S', 'Iridium 35', '' );
 __PACKAGE__->status( add => 24967, iridium => '-', 'Iridium 36', 'Tumbling' );
 __PACKAGE__->status( add => 24968, iridium => 'D', 'Iridium 37', 'Decayed 2018-05-26' );
 __PACKAGE__->status( add => 24969, iridium => 'D', 'Iridium 34', 'Decayed 2018-01-08' );
 __PACKAGE__->status( add => 25039, iridium => 'D', 'Iridium 43', 'Decayed 2018-02-11' );
-__PACKAGE__->status( add => 25040, iridium => 'D', 'Iridium 41', 'Decayed 2018-07-28' );
-__PACKAGE__->status( add => 25041, iridium => 'D', 'Iridium 40', 'Decayed 2018-09-23' );
+__PACKAGE__->status( add => 25040, iridium => '-', 'Iridium 41', 'Tumbling' );
+__PACKAGE__->status( add => 25041, iridium => '-', 'Iridium 40', 'Tumbling' );
 __PACKAGE__->status( add => 25042, iridium => '-', 'Iridium 39', 'Tumbling' );
 __PACKAGE__->status( add => 25043, iridium => '-', 'Iridium 38', 'Tumbling' );
 __PACKAGE__->status( add => 25077, iridium => '-', 'Iridium 42', 'Tumbling' );
 __PACKAGE__->status( add => 25078, iridium => '-', 'Iridium 44', 'Tumbling' );
-__PACKAGE__->status( add => 25104, iridium => '-', 'Iridium 45', 'Tumbling' );
+__PACKAGE__->status( add => 25104, iridium => '+', 'Iridium 45', '' );
 __PACKAGE__->status( add => 25105, iridium => '-', 'Iridium 24', 'Tumbling' );
-__PACKAGE__->status( add => 25106, iridium => 'D', 'Iridium 47', 'Decayed 2018-09-01' );
+__PACKAGE__->status( add => 25106, iridium => 'S', 'Iridium 47', '' );
 __PACKAGE__->status( add => 25107, iridium => 'D', 'Iridium 48', 'Decayed 2001-05-05' );
 __PACKAGE__->status( add => 25108, iridium => 'D', 'Iridium 49', 'Decayed 2018-02-13' );
-__PACKAGE__->status( add => 25169, iridium => 'D', 'Iridium 52', 'Decayed 2018-11-05' );
-__PACKAGE__->status( add => 25170, iridium => 'D', 'Iridium 56', 'Decayed 2018-10-11' );
-__PACKAGE__->status( add => 25171, iridium => 'D', 'Iridium 54', 'Decayed 2019-05-11' );
-__PACKAGE__->status( add => 25172, iridium => 'D', 'Iridium 50', 'Decayed 2018-09-23' );
-__PACKAGE__->status( add => 25173, iridium => 'D', 'Iridium 53', 'Decayed 2018-09-30' );
+__PACKAGE__->status( add => 25169, iridium => '+', 'Iridium 52', '' );
+__PACKAGE__->status( add => 25170, iridium => '+', 'Iridium 56', '' );
+__PACKAGE__->status( add => 25171, iridium => '+', 'Iridium 54', '' );
+__PACKAGE__->status( add => 25172, iridium => '+', 'Iridium 50', '' );
+__PACKAGE__->status( add => 25173, iridium => '+', 'Iridium 53', '' );
 __PACKAGE__->status( add => 25262, iridium => '-', 'Iridium 51', 'Tumbling' );
-__PACKAGE__->status( add => 25263, iridium => 'D', 'Iridium 61', 'Decayed 2019-07-23' );
-__PACKAGE__->status( add => 25272, iridium => 'D', 'Iridium 55', 'Decayed 2019-03-31' );
+__PACKAGE__->status( add => 25263, iridium => 'S', 'Iridium 61', '' );
+__PACKAGE__->status( add => 25272, iridium => 'S', 'Iridium 55', '' );
 __PACKAGE__->status( add => 25273, iridium => '-', 'Iridium 57', 'Tumbling' );
-__PACKAGE__->status( add => 25274, iridium => 'D', 'Iridium 58', 'Decayed 2019-04-07' );
-__PACKAGE__->status( add => 25275, iridium => 'D', 'Iridium 59', 'Decayed 2019-03-11' );
-__PACKAGE__->status( add => 25276, iridium => 'D', 'Iridium 60', 'Decayed 2019-03-17' );
-__PACKAGE__->status( add => 25285, iridium => 'D', 'Iridium 62', 'Decayed 2018-11-07' );
+__PACKAGE__->status( add => 25274, iridium => 'S', 'Iridium 58', '' );
+__PACKAGE__->status( add => 25275, iridium => '+', 'Iridium 59', '' );
+__PACKAGE__->status( add => 25276, iridium => '+', 'Iridium 60', '' );
+__PACKAGE__->status( add => 25285, iridium => 'S', 'Iridium 62', '' );
 __PACKAGE__->status( add => 25286, iridium => '-', 'Iridium 63', 'Tumbling' );
-__PACKAGE__->status( add => 25287, iridium => 'D', 'Iridium 64', 'Decayed 2019-04-01' );
-__PACKAGE__->status( add => 25288, iridium => 'D', 'Iridium 65', 'Decayed 2018-07-19' );
-__PACKAGE__->status( add => 25289, iridium => 'D', 'Iridium 66', 'Decayed 2018-08-23' );
+__PACKAGE__->status( add => 25287, iridium => 'S', 'Iridium 64', '' );
+__PACKAGE__->status( add => 25288, iridium => '-', 'Iridium 65', 'Tumbling' );
+__PACKAGE__->status( add => 25289, iridium => 'S', 'Iridium 66', '' );
 __PACKAGE__->status( add => 25290, iridium => 'D', 'Iridium 67', 'Decayed 2018-07-02' );
 __PACKAGE__->status( add => 25291, iridium => 'D', 'Iridium 68', 'Decayed 2018-06-06' );
 __PACKAGE__->status( add => 25319, iridium => '-', 'Iridium 69', 'Tumbling' );
 __PACKAGE__->status( add => 25320, iridium => '-', 'Iridium 71', 'Tumbling' );
-__PACKAGE__->status( add => 25342, iridium => 'D', 'Iridium 70', 'Decayed 2018-10-11' );
+__PACKAGE__->status( add => 25342, iridium => '+', 'Iridium 70', '' );
 __PACKAGE__->status( add => 25343, iridium => 'D', 'Iridium 72', 'Decayed 2018-05-14' );
 __PACKAGE__->status( add => 25344, iridium => '-', 'Iridium 73', 'Tumbling' );
 __PACKAGE__->status( add => 25345, iridium => 'D', 'Iridium 74', 'Decayed 2017-06-11' );
 __PACKAGE__->status( add => 25346, iridium => 'D', 'Iridium 75', 'Decayed 2018-07-10' );
 __PACKAGE__->status( add => 25431, iridium => 'D', 'Iridium 3', 'Decayed 2018-02-08' );
-__PACKAGE__->status( add => 25432, iridium => 'D', 'Iridium 76', 'Decayed 2018-08-28' );
+__PACKAGE__->status( add => 25432, iridium => 'S', 'Iridium 76', '' );
 __PACKAGE__->status( add => 25467, iridium => '-', 'Iridium 82', 'Tumbling' );
-__PACKAGE__->status( add => 25468, iridium => 'D', 'Iridium 81', 'Decayed 2018-07-17' );
-__PACKAGE__->status( add => 25469, iridium => 'D', 'Iridium 80', 'Decayed 2018-08-12' );
+__PACKAGE__->status( add => 25468, iridium => '-', 'Iridium 81', 'Tumbling' );
+__PACKAGE__->status( add => 25469, iridium => 'S', 'Iridium 80', '' );
 __PACKAGE__->status( add => 25470, iridium => 'D', 'Iridium 79', 'Decayed 2000-11-29' );
 __PACKAGE__->status( add => 25471, iridium => 'D', 'Iridium 77', 'Decayed 2017-09-22' );
 __PACKAGE__->status( add => 25527, iridium => '-', 'Iridium 2', 'Tumbling' );
-__PACKAGE__->status( add => 25528, iridium => 'D', 'Iridium 86', 'Decayed 2018-10-05' );
+__PACKAGE__->status( add => 25528, iridium => '+', 'Iridium 86', '' );
 __PACKAGE__->status( add => 25529, iridium => 'D', 'Iridium 85', 'Decayed 2000-12-30' );
-__PACKAGE__->status( add => 25530, iridium => 'D', 'Iridium 84', 'Decayed 2018-11-04' );
-__PACKAGE__->status( add => 25531, iridium => 'D', 'Iridium 83', 'Decayed 2018-11-05' );
-__PACKAGE__->status( add => 25577, iridium => 'D', 'Iridium 20', 'Decayed 2018-10-22' );
-__PACKAGE__->status( add => 25578, iridium => 'D', 'Iridium 11', 'Decayed 2018-10-22' );
-__PACKAGE__->status( add => 25777, iridium => 'D', 'Iridium 14', 'Decayed 2019-03-15' );
+__PACKAGE__->status( add => 25530, iridium => '+', 'Iridium 84', '' );
+__PACKAGE__->status( add => 25531, iridium => '+', 'Iridium 83', '' );
+__PACKAGE__->status( add => 25577, iridium => 'S', 'Iridium 20', '' );
+__PACKAGE__->status( add => 25578, iridium => 'S', 'Iridium 11', '' );
+__PACKAGE__->status( add => 25777, iridium => '+', 'Iridium 14', '' );
 __PACKAGE__->status( add => 25778, iridium => 'D', 'Iridium 21', 'Decayed 2018-05-24' );
-__PACKAGE__->status( add => 27372, iridium => 'D', 'Iridium 91', 'Decayed 2019-03-13' );
-__PACKAGE__->status( add => 27373, iridium => 'D', 'Iridium 90', 'Decayed 2019-01-23' );
+__PACKAGE__->status( add => 27372, iridium => '+', 'Iridium 91', '' );
+__PACKAGE__->status( add => 27373, iridium => '-', 'Iridium 90', 'Tumbling' );
 __PACKAGE__->status( add => 27374, iridium => 'D', 'Iridium 94', 'Decayed 2018-04-18' );
-__PACKAGE__->status( add => 27375, iridium => 'D', 'Iridium 95', 'Decayed 2019-03-25' );
-__PACKAGE__->status( add => 27376, iridium => '-', 'Iridium 96', 'SpaceTrack' );
-__PACKAGE__->status( add => 27450, iridium => 'D', 'Iridium 97', 'Decayed 2019-12-27' );
-__PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-08-24' );
+__PACKAGE__->status( add => 27375, iridium => '+', 'Iridium 95', '' );
+__PACKAGE__->status( add => 27376, iridium => '-', 'Iridium 96', 'Tumbling' );
+__PACKAGE__->status( add => 27450, iridium => 'S', 'Iridium 97', '' );
+__PACKAGE__->status( add => 27451, iridium => 'S', 'Iridium 98', '' );
 
 # Summary:
-# Operational [+]: 0
-#       Spare [S]: 0
-#    Tumbling [-]: 32
-#     Decayed [D]: 65
+# Operational [+]: 17
+#       Spare [S]: 17
+#    Tumbling [-]: 38
+#     Decayed [D]: 25
 
 1;
 
@@ -1871,14 +1922,11 @@ whose work this module would never have existed:
 Ron Lee and the members of his team who collected Iridium magnitude
 data.
 
-Randy John, the author of SKYSAT (C<http://home.comcast.net/~skysat/>),
+Randy John, the author of SKYSAT (L<http://home.comcast.net/~skysat/>),
 whose Turbo Pascal implementation of the geometry calculation (at
-C<http://home.comcast.net/~skysat/algo.txt> provided the basic mechanism
+L<http://home.comcast.net/~skysat/algo.txt> provided the basic mechanism
 for my own geometry calculation, and who made Ron Lee's data available
-on the SKYSAT web site. Unfortunately Comcast has long since stopped
-providing personal pages, and I have found nothing more recent. The
-most-recent capture of this by the Internet Archive's Wayback Machine is
-September 19 2015.
+on the SKYSAT web site.
 
 The contributors to the Visual Satellite Observer's Home Page
 (L<http://www.satobs.org/satintro.html>), particularly the
@@ -1888,10 +1936,8 @@ effort.
 
 =head1 BUGS
 
-Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-Coord-ECI-TLE-Iridium>,
-L<https://github.com/trwyant/perl-Astro-Coord-ECI-TLE-Iridium/issues>, or in
-electronic mail to the author.
+Bugs can be reported to the author by mail, or through
+L<http://rt.cpan.org/>.
 
 =head1 AUTHOR
 
@@ -1899,7 +1945,7 @@ Thomas R. Wyant, III (F<wyant at cpan dot org>)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2022 by Thomas R. Wyant, III
+Copyright (C) 2005-2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
